function createSubmitScript(outputFilename, jobName, quotedLogFile, quotedScriptName, ...
    environmentVariables, additionalSubmitArgs)
% Create a script that sets the correct environment variables and then
% executes the Slurm sbatch command.

% Copyright 2010-2018 The MathWorks, Inc.
% modified to set a default partition in environmemnt
%      and to load the module CUDA-Toolkit for GPU use     (SH@UOL 2019)

% Open file in binary mode to make it cross-platform.
fid = fopen(outputFilename, 'w');
if fid < 0
    error('parallelexamples:GenericSLURM:FileError', ...
        'Failed to open file %s for writing', outputFilename);
end

% Specify Shell to use
fprintf(fid, '#!/bin/sh\n');

% Write the commands to set and export environment variables
for ii = 1:size(environmentVariables, 1)
    fprintf(fid, '%s=%s\n', environmentVariables{ii,1}, environmentVariables{ii,2});
    fprintf(fid, 'export %s\n', environmentVariables{ii,1});
end

% add a command to select a default partition by environment (added May 17 by SH)
fprintf(fid, '# set SLURM_PARTITION in case it is not set by user\n');
fprintf(fid, 'PART=`groups $USER | grep &> /dev/null ''\\beddy\\b'' && echo eddy.p || echo carl.p`\n');
fprintf(fid, 'export SBATCH_PARTITION=$PART\n'); 

% add loading of module CUDA-Toolkit/recent in case a GPU was requested
fprintf(fid, '# load CUDA-Toolkit/recent for GPU use\n');
fprintf(fid, 'module load CUDA-Toolkit/recent\n');

% Generate the command to run and write it.
commandToRun = getSubmitString(jobName, quotedLogFile, quotedScriptName, ...
    additionalSubmitArgs);
fprintf(fid, '%s\n', commandToRun);

% Close the file
fclose(fid);
